@@ -63,6 +63,11 @@ class LoginConfig(BaseModel):
     BOT_TOKEN: str = ""
 
 
+class BotMessages(BaseModel):
+    start: str = "Hi! I am alive"
+    bot_help: str = "For details visit github.com/aahnik/tgcf"
+
+
 class Config(BaseModel):
     """The blueprint for tgcf's whole config."""
 
@@ -70,13 +75,14 @@ class Config(BaseModel):
     pid: int = 0
     login: LoginConfig = LoginConfig()
     admins: List[Union[int, str]] = []
-    forwards: List[Forward] = [Forward() for i in range(10)]
+    forwards: List[Forward] = []
     show_forwarded_from: bool = False
     mode: int = 0  # 0: live, 1:past
     live: LiveSettings = LiveSettings()
     past: PastSettings = PastSettings()
 
     plugins: PluginConfig = PluginConfig()
+    bot_messages = BotMessages()
 
 
 def write_config_to_file(config: Config):
@@ -206,6 +212,3 @@ if PASSWORD == "tgcf":
 from_to = {}
 is_bot: Optional[bool] = None
 logging.info("config.py got executed")
-
-with open("logs.txt", "w") as file:
-    file.write("config file loaded")
